@@ -7,7 +7,7 @@ class ReqIFNamespaceInfo:  # pylint: disable=too-many-instance-attributes
         doctype_is_present: bool,
         encoding: str,
         namespace: str,
-        configuration: str,
+        configuration: Optional[str],
         namespace_id: Optional[str],
         namespace_xhtml: Optional[str],
         schema_namespace: Optional[str],
@@ -17,7 +17,7 @@ class ReqIFNamespaceInfo:  # pylint: disable=too-many-instance-attributes
         self.doctype_is_present: bool = doctype_is_present
         self.encoding: str = encoding
         self.namespace: str = namespace
-        self.configuration: str = configuration
+        self.configuration: Optional[str] = configuration
         self.namespace_id: Optional[str] = namespace_id
         self.namespace_xhtml: Optional[str] = namespace_xhtml
         self.schema_namespace: Optional[str] = schema_namespace
